@@ -6,8 +6,10 @@ This package provides agent implementations and conversation management for Stre
 
 from .agents import Agent as Agent
 from .conversation import Conversation as Conversation
+from .agent_launcher import AgentLauncher as AgentLauncher
 
 __all__ = [
     "Agent",
     "Conversation",
+    "AgentLauncher",
 ]
