@@ -142,6 +142,7 @@ class EventManager:
         self._shutdown = False
         self._silent_events: set[type] = set()
         self._handler_tasks: Dict[uuid.UUID, asyncio.Task[Any]] = {}
+        self._received_event = asyncio.Event()
 
         self.register(ExceptionEvent)
         self.register(HealthCheckEvent)
@@ -213,6 +214,7 @@ class EventManager:
         em._queue = self._queue
         em._silent_events = self._silent_events
         em._processing_task = None  # Clear the stopped task reference
+        em._received_event = self._received_event
 
     def register_events_from_module(
         self, module, prefix="", ignore_not_compatible=True
@@ -331,6 +333,11 @@ class EventManager:
         is_union = False
         annotations = typing.get_type_hints(function)
 
+        if not asyncio.iscoroutinefunction(function):
+            raise RuntimeError(
+                "Handlers must be coroutines. Use async def handler(event: EventType):"
+            )
+
         for name, event_class in annotations.items():
             origin = get_origin(event_class)
             events: typing.List[type] = []
@@ -353,7 +360,7 @@ class EventManager:
                     subscribed = True
                     self._handlers.setdefault(event_type, []).append(function)
                     module_name = getattr(function, "__module__", "unknown")
-                    logger.info(
+                    logger.debug(
                         f"Handler {function.__name__} from {module_name} registered for event {event_type}"
                     )
                 elif not self._ignore_unknown_events:
@@ -362,7 +369,7 @@ class EventManager:
                     )
                 else:
                     module_name = getattr(function, "__module__", "unknown")
-                    logger.info(
+                    logger.debug(
                         f"Event {sub_event} - {event_type} is not registered – skipping handler {function.__name__} from {module_name}."
                     )
         return function
@@ -400,17 +407,21 @@ class EventManager:
             else:
                 # No matching event class found
                 if self._ignore_unknown_events:
-                    logger.info(f"Protobuf event not registered: {proto_type}")
+                    logger.debug(f"Protobuf event not registered: {proto_type}")
                     return
                 else:
                     raise RuntimeError(f"Protobuf event not registered: {proto_type}")
 
         # Validate event is registered (handles both BaseEvent and generated protobuf events)
         if hasattr(event, "type") and event.type in self._events:
-            # logger.info(f"Received event {_truncate_event_for_logging(event)}")
+            logger.debug(f"Received event {_truncate_event_for_logging(event)}")
             return event
         elif self._ignore_unknown_events:
-            logger.info(f"Event not registered {_truncate_event_for_logging(event)}")
+            logger.warning(
+                f"Event not registered {_truncate_event_for_logging(event)}. "
+                "Use self.register(EventClass) to register it. "
+                "Or self.register_events_from_module(module) to register all events from a module."
+            )
         else:
             raise RuntimeError(f"Event not registered {event}")
 
@@ -467,6 +478,8 @@ class EventManager:
             if event:
                 self._queue.append(event)
 
+        self._received_event.set()
+
     async def wait(self, timeout: float = 10.0):
         """
         Wait for all queued events to be processed.
@@ -477,16 +490,15 @@ class EventManager:
             timeout: Maximum time to wait for processing to complete
         """
         start_time = asyncio.get_event_loop().time()
-        while self._queue and (asyncio.get_event_loop().time() - start_time) < timeout:
+        while (asyncio.get_event_loop().time() - start_time) < timeout:
+            if not self._queue and not self._handler_tasks:
+                break
             await asyncio.sleep(0.01)
 
-        if self._handler_tasks:
-            await asyncio.wait(list(self._handler_tasks.values()))
-
     def _start_processing_task(self):
         """Start the background event processing task."""
         if self._processing_task and not self._processing_task.done():
-            return  # Already running
+            return
 
         loop = asyncio.get_running_loop()
         self._processing_task = loop.create_task(self._process_events_loop())
@@ -507,7 +519,7 @@ class EventManager:
                     await self._process_single_event(event)
                 except asyncio.CancelledError as exc:
                     cancelled_exc = exc
-                    logger.info(
+                    logger.debug(
                         f"Event processing task was cancelled, processing remaining events, {len(self._queue)}"
                     )
                     await self._process_single_event(event)
@@ -521,13 +533,15 @@ class EventManager:
                 )
                 for task_id in cleanup_ids:
                     self._handler_tasks.pop(task_id)
-                await asyncio.sleep(0.0001)
+
+                await self._received_event.wait()
+                self._received_event.clear()
 
     async def _run_handler(self, handler, event):
         try:
             return await handler(event)
         except Exception as exc:
-            self._queue.appendleft(ExceptionEvent(exc, handler))  # type: ignore[arg-type]
+            self.send(ExceptionEvent(exc, handler))
             module_name = getattr(handler, "__module__", "unknown")
             logger.exception(
                 f"Error calling handler {handler.__name__} from {module_name} for event {event.type}"
@@ -536,10 +550,11 @@ class EventManager:
     async def _process_single_event(self, event):
         """Process a single event."""
         for handler in self._handlers.get(event.type, []):
-            #module_name = getattr(handler, '__module__', 'unknown')
+            module_name = getattr(handler, "__module__", "unknown")
             if event.type not in self._silent_events:
-                pass
-                #logger.info(f"Called handler {handler.__name__} from {module_name} for event {event.type}")
+                logger.debug(
+                    f"Called handler {handler.__name__} from {module_name} for event {event.type}"
+                )
 
             loop = asyncio.get_running_loop()
             handler_task = loop.create_task(self._run_handler(handler, event))
