@@ -1,26 +1,24 @@
 from __future__ import annotations
 
 from typing import (
-    Any,
     Optional,
 )
 
-from getstream.video.rtc.audio_track import AudioStreamTrack
-from vision_agents.core.edge.types import PcmData, Participant
+from getstream.video.rtc.track_util import PcmData
+from vision_agents.core.edge.types import Participant
 
 
 import abc
 import logging
 import uuid
 
-
-from . import events, LLM
+from . import events, OmniLLM
 
 
 logger = logging.getLogger(__name__)
 
 
-class Realtime(LLM, abc.ABC):
+class Realtime(OmniLLM):
     """
     Realtime is an abstract base class for LLMs that can receive audio and video
 
@@ -37,8 +35,9 @@ class Realtime(LLM, abc.ABC):
         - Transcript outgoing audio
 
     """
-    fps : int = 1
-    session_id : str # UUID to identify this session
+
+    fps: int = 1
+    session_id: str  # UUID to identify this session
 
     def __init__(
         self,
@@ -50,10 +49,6 @@ class Realtime(LLM, abc.ABC):
         self.provider_name = "realtime_base"
         self.session_id = str(uuid.uuid4())
         self.fps = fps
-        # The most common style output track (webrtc)
-        self.output_track: AudioStreamTrack = AudioStreamTrack(
-            framerate=48000, stereo=True, format="s16"
-        )
         # Store current participant for user speech transcription events
         self._current_participant: Optional[Participant] = None
 
@@ -65,10 +60,6 @@ class Realtime(LLM, abc.ABC):
         self, pcm: PcmData, participant: Optional[Participant] = None
     ): ...
 
-    async def _watch_video_track(self, track: Any, **kwargs) -> None:
-        """Optionally overridden by providers that support video input."""
-        return None
-
     async def _stop_watching_video_track(self) -> None:
         """Optionally overridden by providers that support video input."""
         return None
@@ -100,31 +91,27 @@ class Realtime(LLM, abc.ABC):
         )
         self.events.send(event)
 
-    def _emit_audio_input_event(
-        self, audio_data, sample_rate=16000, user_metadata=None
-    ):
+    def _emit_audio_input_event(self, audio_data: PcmData, user_metadata=None):
         """Emit a structured audio input event."""
         event = events.RealtimeAudioInputEvent(
             session_id=self.session_id,
             plugin_name=self.provider_name,
-            audio_data=audio_data,
-            sample_rate=sample_rate,
-            user_metadata=user_metadata,
+            data=audio_data,
+            participant=user_metadata,
         )
         self.events.send(event)
 
     # TODO: discussion around event vs output_track... why do we have both?
     def _emit_audio_output_event(
-        self, audio_data, sample_rate=16000, response_id=None, user_metadata=None
+        self, audio_data: PcmData, response_id=None, user_metadata=None
     ):
         """Emit a structured audio output event."""
         event = events.RealtimeAudioOutputEvent(
             session_id=self.session_id,
             plugin_name=self.provider_name,
-            audio_data=audio_data,
-            sample_rate=sample_rate,
+            data=audio_data,
             response_id=response_id,
-            user_metadata=user_metadata,
+            participant=user_metadata,
         )
         self.events.send(event)
 
@@ -144,7 +131,7 @@ class Realtime(LLM, abc.ABC):
             response_id=response_id,
             is_complete=is_complete,
             conversation_item_id=conversation_item_id,
-            user_metadata=user_metadata,
+            participant=user_metadata,
         )
         self.events.send(event)
 
@@ -160,7 +147,7 @@ class Realtime(LLM, abc.ABC):
             status=status,
             role=role,
             content=content,
-            user_metadata=user_metadata,
+            participant=user_metadata,
         )
         self.events.send(event)
 
@@ -171,7 +158,7 @@ class Realtime(LLM, abc.ABC):
             plugin_name=self.provider_name,
             error=error,
             context=context,
-            user_metadata=user_metadata,
+            participant=user_metadata,
         )
         self.events.send(event)
 
@@ -186,7 +173,7 @@ class Realtime(LLM, abc.ABC):
             plugin_name=self.provider_name,
             text=text,
             original=original,
-            user_metadata=self._current_participant,
+            participant=self._current_participant,
         )
         self.events.send(event)
 
