@@ -1,8 +1,6 @@
 from .turn_detection import (
     TurnEvent,
-    TurnEventData,
     TurnDetector,
-    TurnDetection,
 )
 from .events import (
     TurnStartedEvent,
@@ -13,9 +11,7 @@ from .events import (
 __all__ = [
     # Base classes and types
     "TurnEvent",
-    "TurnEventData",
     "TurnDetector",
-    "TurnDetection",
     # Events
     "TurnStartedEvent",
     "TurnEndedEvent",
